@@ -190,14 +190,9 @@ class SSHClient(object):
         if os.path.isfile(local_path):
             subprocess.run(['rm', '-rf', local_path], capture_output=True, text=True)
         self.__sftp.get(remote_path, local_path)
-        if os.path.exists(local_path):
-            log.info(
-                f" {self.__ip}:{self.__port} | Success to copy file from remote {remote_path} to local host{local_path}:OK.")
-            return True
-        else:
-            log.error(
-                f" {self.__ip}:{self.__port} | failed to copy file from remote {remote_path} to local host{local_path}:Error.")
-            return False
+        log.info(
+            f" {self.__ip}:{self.__port} | Success to copy file from remote {remote_path} to local host{local_path}:OK.")
+        return True
 
     def scp_file_to_local(self, remote_path, local_path,timeout=120):
         try:
